@@ -1,4 +1,5 @@
 from scrapeanything.scraper.scraper import Scraper
+from scrapeanything.utils.config import Config
 
 # import undetected_chromedriver.v2 as webdriver
 from selenium import webdriver
@@ -21,52 +22,42 @@ import base64
 
 class Selenium(Scraper):
 
-    def __init__(self, headless: bool=True, window: dict={}, user_dir: str=None):
+    def __init__(self, config: Config, headless: bool=True, window: dict={}, user_dir: str=None):
         options = webdriver.ChromeOptions()
 
+        #region options
+        options.add_argument('--no-sandbox')
+        options.add_argument('--log-level=3')
+        options.add_argument('disable-infobars')
+        options.add_argument('--disable-extensions')
+        options.add_argument('--disable-dev-shm-usage')
+
+        window_size = window['size'] if 'size' in window else []
+
+        if len(window_size) == 0:
+            options.add_argument('start-maximized')
+
+        if headless is True:
+            options.add_argument('headless')
+
+        LOGGER.setLevel(logging.WARNING)
+
+        options.add_argument('--disable-blink-features=AutomationControlled')
+        options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36")
+        #endregion options
+
         url = self.config.get(section='SELENIUM', key='url')
 
-        options.add_argument('--no-sandbox')
-        options.add_argument('--disable-dev-shm-usage')
-        options.add_argument('start-maximized')
-        self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
+        if url is not None:
+            self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
+        elif platform.system() == 'Windows':
+            self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
+        elif platform.system() == 'Linux':
+            self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
 
-        # #region undetected_chromedriver
-        # # setting profile
-        # # another way to set profile is the below (which takes precedence if both variants are used
-        # if user_dir is not None:
-        #     options.add_argument(f'--user-data-dir={user_dir}')
-        # # just some options passing in to skip annoying popups
-        # options.add_argument('--no-first-run --no-service-autorun --password-store=basic')
-        # #endregion undetected_chromedriver
-
-        # options.add_argument('--no-sandbox')
-        # options.add_argument('--log-level=3')
-        # options.add_argument('disable-infobars')
-        # options.add_argument('--disable-extensions')
-        # options.add_argument('--disable-dev-shm-usage')
-
-        # window_size = window['size'] if 'size' in window else []
-
-        # if len(window_size) == 0:
-        #     options.add_argument('start-maximized')
-
-        # if headless is True:
-        #     options.add_argument('headless')
-
-        # LOGGER.setLevel(logging.WARNING)
-
-        # options.add_argument('--disable-blink-features=AutomationControlled')
-        # options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36")
-
-        # if platform.system() == 'Windows':
-        #     self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
-        # elif platform.system() == 'Linux':
-        #     self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
-
-        # if len(window_size) > 0:
-        #     self.driver.set_window_position(x=0, y=0)
-        #     self.driver.set_window_size(width=window_size[0], height=window_size[1])
+        if len(window_size) > 0:
+            self.driver.set_window_position(x=0, y=0)
+            self.driver.set_window_size(width=window_size[0], height=window_size[1])
 
         super().__init__()
 
